@@ -3,7 +3,6 @@ import itertools
 
 import math
 
-from tacle.indexing import Typing, Block
 from tacle.engine import evaluate
 from tacle.core.virtual_template import VirtualLookup, VirtualConditionalAggregate
 from tacle.core.template import *
@@ -539,26 +538,26 @@ class InternalSolvingStrategy(DictSolvingStrategy):
             size = 2
 
             for assignment in assignments:
-                r_group, p_group = [assignment[v.name] for v in [c.result, c.projected]]
+                r_group, p_group = [assignment[v.name] for v in [c.result, c.projected]]  # type: Block
                 if p_group not in masks:
                     bool_mask = numpy.vectorize(blank_filter(p_group.data)[1])(
                         p_group.data
                     )
                     masks[p_group] = numpy.vectorize(lambda e: 1 if e else 0)(bool_mask)
-                p_masked = masks[p_group] if p_group.row else masks[p_group].T
+                p_masked = masks[p_group] if p_group.orientation == Orientation.horizontal else masks[p_group].T
 
                 def check(start, end):
                     result = numpy.sum(p_masked[start:end, :], 0)
                     if numpy.vectorize(lambda e: e == 1)(result).all():
-                        p_subgroup = p_group.vector_subset(start + 1, end)
+                        p_subgroup = p_group.sub_block(start, end - start)
                         p_data = (
                             p_subgroup.data if p_subgroup.row else p_subgroup.data.T
                         )
                         if equal_v(
-                            r_group.get_vector(r_i + 1),
+                            r_group.vector(r_i),
                             Operation.SUM.aggregate(p_data, 0),
                         ).all():
-                            r_subgroup = r_group.vector_subset(r_i + 1, r_i + 1)
+                            r_subgroup = r_group.sub_block(r_i, 1)
                             solutions.append(
                                 {
                                     c.result.name: r_subgroup,
@@ -569,12 +568,12 @@ class InternalSolvingStrategy(DictSolvingStrategy):
                     return False
 
                 max_range = MaxRange(check)
-                for r_i in range(r_group.vectors()):
+                for r_i in range(r_group.vector_count()):
                     if r_group == p_group:
                         max_range.find(0, r_i, size)
-                        max_range.find(r_i + 1, p_group.vectors(), size)
+                        max_range.find(r_i + 1, p_group.vector_count(), size)
                     else:
-                        max_range.find(0, p_group.vectors(), size)
+                        max_range.find(0, p_group.vector_count(), size)
             return solutions
 
         def equality(c: Equal, assignments, _):
